#!/bin/sh -e

# Move to configuration directory
cd /user/spf/etc

# Create configuration and version files
ln -fs /user/spf/etc/global_conf.json /tmp/packet_forwarder.conf
echo spf 3.1.0-klk13 +hal_libloragw_4.1.3-klk3 > /tmp/packet_forwarder_version.txt

# Open firewall ports
iptables_accept() {
	local PORT=$(sed -n 's/^.*"'${2}'": *\([0-9]*\).*$/\1/p' ${1})
	[ -z "${PORT}" ] && return
	local RULE="OUTPUT -t filter -p udp --dport $PORT -j ACCEPT"
	iptables -C $RULE 2> /dev/null || iptables -A $RULE
	local RULE="INPUT -t filter -p udp --sport $PORT -j ACCEPT"
	iptables -C $RULE 2> /dev/null || iptables -A $RULE
}

iptables_accept /tmp/packet_forwarder.conf serv_port_up
iptables_accept /tmp/packet_forwarder.conf serv_port_down

(
	# Lock on pid file
	exec 8> /var/run/packet_forwarder.pid
	flock -n -x 8
	trap "rm -f /var/run/packet_forwarder.pid" EXIT

	# Start packet forwarder
	/user/spf/bin/spf 2>&1 | logger -p local1.notice -t spf &
	trap "killall -q spf" INT QUIT TERM

	# Update pid and wait for it
	pidof spf >&8
	wait
) &
